@@ -24,15 +24,16 @@ type CreateRequest struct {
 	IssueType string
 	// ParentIssueKey is required when creating a sub-task for classic project.
 	// This can also be used to attach epic for next-gen project.
-	ParentIssueKey string
-	Summary        string
-	Body           interface{} // string in v1/v2 and adf.ADF in v3
-	Reporter       string
-	Assignee       string
-	Priority       string
-	Labels         []string
-	Components     []string
-	FixVersions    []string
+	ParentIssueKey  string
+	Summary         string
+	Body            interface{} // string in v1/v2 and adf.ADF in v3
+	Reporter        string
+	Assignee        string
+	Priority        string
+	Labels          []string
+	Components      []string
+	FixVersions     []string
+	AffectsVersions []string
 	// EpicField is the dynamic epic field name
 	// that changes per jira installation.
 	EpicField string
@@ -202,6 +203,18 @@ func (*Client) getRequestData(req *CreateRequest) *createRequest {
 		}
 		data.Fields.M.FixVersions = versions
 	}
+	if len(req.AffectsVersions) > 0 {
+		versions := make([]struct {
+			Name string `json:"name,omitempty"`
+		}, 0, len(req.AffectsVersions))
+
+		for _, v := range req.AffectsVersions {
+			versions = append(versions, struct {
+				Name string `json:"name,omitempty"`
+			}{v})
+		}
+		data.Fields.M.AffectsVersions = versions
+	}
 	constructCustomFields(req.CustomFields, req.configuredCustomFields, &data)
 
 	return &data
@@ -287,7 +300,9 @@ type createFields struct {
 	FixVersions []struct {
 		Name string `json:"name,omitempty"`
 	} `json:"fixVersions,omitempty"`
-
+	AffectsVersions []struct {
+		Name string `json:"name,omitempty"`
+	} `json:"versions,omitempty"`
 	epicField    string
 	customFields customField
 }
